/*
 * Copyright (c) 2022, salesforce.com, inc.
 * All rights reserved.
 * Licensed under the BSD 3-Clause license.
 * For full license text, see LICENSE.txt file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
import { Messages } from '@salesforce/core';
import { SfCommand, Flags } from '@salesforce/sf-plugins-core';
import { SourceTracking } from '@salesforce/source-tracking';
import { ForceIgnore } from '@salesforce/source-deploy-retrieve';
import { printTables, compileResults, getConflictFiles } from '../../../utils/previewOutput.js';
Messages.importMessagesDirectoryFromMetaUrl(import.meta.url);
const messages = Messages.loadMessages('@salesforce/plugin-deploy-retrieve', 'retrieve.metadata.preview');
export default class RetrieveMetadataPreview extends SfCommand {
    static description = messages.getMessage('description');
    static summary = messages.getMessage('summary');
    static examples = messages.getMessages('examples');
    static requiresProject = true;
    static aliases = ['retrieve:metadata:preview'];
    static deprecateAliases = true;
    static flags = {
        'ignore-conflicts': Flags.boolean({
            char: 'c',
            summary: messages.getMessage('flags.ignore-conflicts.summary'),
            description: messages.getMessage('flags.ignore-conflicts.description'),
            default: false,
        }),
        'target-org': Flags.requiredOrg(),
        concise: Flags.boolean({
            summary: messages.getMessage('flags.concise.summary'),
            default: false,
        }),
    };
    async run() {
        const { flags } = await this.parse(RetrieveMetadataPreview);
        const stl = await SourceTracking.create({
            org: flags['target-org'],
            project: this.project,
            ignoreConflicts: flags['ignore-conflicts'],
        });
        const forceIgnore = ForceIgnore.findAndCreate(this.project.getDefaultPackage().path);
        const [componentSet, filesWithConflicts, remoteDeletes] = await Promise.all([
            stl.remoteNonDeletesAsComponentSet(),
            getConflictFiles(stl, flags['ignore-conflicts']),
            stl.getChanges({ origin: 'remote', state: 'delete', format: 'SourceComponent' }),
        ]);
        const output = compileResults({
            componentSet,
            projectPath: this.project.getPath(),
            filesWithConflicts,
            forceIgnore,
            baseOperation: 'retrieve',
            remoteDeletes,
        });
        if (!this.jsonEnabled()) {
            printTables(output, 'retrieve', flags.concise);
        }
        return output;
    }
}
//# sourceMappingURL=preview.js.map